==> morphlingjs-0.1.91.tgz: package/bin/cli/morphling-stop.js <==
#! /usr/bin/env node
'use strict';

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _commander = require('commander');

var _commander2 = _interopRequireDefault(_commander);

var _shelljs = require('shelljs');

var _shelljs2 = _interopRequireDefault(_shelljs);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _getInstalledPath = require('get-installed-path');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

_commander2.default.option('-v, --verbose', 'Print all the things').option('-p, --port <port>', 'A port number', parseInt).parse(process.argv);

(0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee() {
    var verbose, installedPath;
    return _regenerator2.default.wrap(function _callee$(_context) {
        while (1) {
            switch (_context.prev = _context.next) {
                case 0:
                    verbose = _commander2.default.verbose || false;


                    if (!_shelljs2.default.which('docker')) {
                        console.log(_chalk2.default.red(' \uD83D\uDE31 Morphling requires docker to be able to run. \uD83D\uDE31 '));
                        _shelljs2.default.exit(1);
                    }

                    if (!_shelljs2.default.which('docker-compose')) {
                        console.log(_chalk2.default.red(' \uD83D\uDE31 Morphling requires docker-compose to be able to run. \uD83D\uDE31 '));
                        _shelljs2.default.exit(1);
                    }
                    _context.next = 5;
                    return (0, _getInstalledPath.getInstalledPath)('morphlingjs');

                case 5:
                    installedPath = _context.sent;


                    if (!verbose) {
                        _shelljs2.default.exec('NODE_PORT=8883 && (cd ' + installedPath + ' && docker-compose stop) > /dev/null 2>&1');
                    } else {
                        _shelljs2.default.exec('NODE_PORT=8883 && (cd ' + installedPath + ' && docker-compose stop)');
                    }

                    console.log(_chalk2.default.green('Morphling instance was killed \uD83D\uDD96'));

                case 8:
                case 'end':
                    return _context.stop();
            }
        }
    }, _callee, undefined);
}))();

==> morphlingjs-0.1.93.tgz: package/bin/cli/morphling-stop.js <==
#! /usr/bin/env node
'use strict';

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _commander = require('commander');

var _commander2 = _interopRequireDefault(_commander);

var _shelljs = require('shelljs');

var _shelljs2 = _interopRequireDefault(_shelljs);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _util = require('./utils/util');

var utilFunctions = _interopRequireWildcard(_util);

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

_commander2.default.option('-v, --verbose', 'Print all the things').option('-p, --port <port>', 'A port number', parseInt).parse(process.argv);

(0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee() {
    var port, config, verbose, installedPath;
    return _regenerator2.default.wrap(function _callee$(_context) {
        while (1) {
            switch (_context.prev = _context.next) {
                case 0:
                    port = void 0;
                    _context.next = 3;
                    return utilFunctions.returnConfigIfExists();

                case 3:
                    config = _context.sent;


                    if (config) {
                        console.log(_chalk2.default.white('Starting morphling using config file...'));
                        port = config.port;
                    } else {
                        port = _commander2.default.port || 8883;
                    }

                    verbose = _commander2.default.verbose || false;


                    if (!_shelljs2.default.which('docker')) {
                        console.log(_chalk2.default.red(' \uD83D\uDE31 Morphling requires docker to be able to run. \uD83D\uDE31 '));
                        _shelljs2.default.exit(1);
                    }

                    if (!_shelljs2.default.which('docker-compose')) {
                        console.log(_chalk2.default.red(' \uD83D\uDE31 Morphling requires docker-compose to be able to run. \uD83D\uDE31 '));
                        _shelljs2.default.exit(1);
                    }
                    _context.next = 10;
                    return getInstalledPath('morphlingjs');

                case 10:
                    installedPath = _context.sent;


                    if (!verbose) {
                        _shelljs2.default.exec('cd ' + installedPath + ' && NODE_PORT=' + port + ' docker-compose stop > /dev/null 2>&1');
                    } else {
                        _shelljs2.default.exec('cd ' + installedPath + ' && NODE_PORT=' + port + ' docker-compose stop');
                    }

                    console.log(_chalk2.default.green('Morphling instance was killed \uD83D\uDD96'));

                case 13:
                case 'end':
                    return _context.stop();
            }
        }
    }, _callee, undefined);
}))();
